@@ -13,10 +13,15 @@ pub enum Error {
     MismatchedShapes(usize, usize),
     #[error("Values must be finite and not `Inf`, `-Inf` or `NaN`")]
     InvalidValues,
+    #[error("Rows of initial parameter ({rows}) must be the same as the number of features ({n_features})")]
+    InitialParameterFeaturesMismatch { rows: usize, n_features: usize },
+    #[error("Columns of initial parameter ({cols}) must be the same as the number of classes ({n_classes})")]
+    InitialParameterClassesMismatch { cols: usize, n_classes: usize },
+
     #[error("gradient_tolerance must be a positive, finite number")]
     InvalidGradientTolerance,
-    #[error("Size of initial parameter guess must be the same as the number of columns in the feature matrix `x`")]
-    InvalidInitialParametersGuessSize,
-    #[error("Initial parameter guess must be finite")]
-    InvalidInitialParametersGuess,
+    #[error("alpha must be a positive, finite number")]
+    InvalidAlpha,
+    #[error("Initial parameters must be finite")]
+    InvalidInitialParameters,
 }
